summaryrefslogtreecommitdiffstats
path: root/kmailcvt/filter_pmail.hxx
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
commitf4fae92b6768541e2952173c3d4b09040f95bf7e (patch)
treed8c5d93232235cd635f3310b4d95490df181ba2d /kmailcvt/filter_pmail.hxx
parent125c0a08265b75a133644d3b55f47e37c919f45d (diff)
downloadtdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.tar.gz
tdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.zip
Moved kpilot from kdepim to applications, as the core Trinity libraries should not contain hardware-dependent software
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1221127 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmailcvt/filter_pmail.hxx')
-rw-r--r--kmailcvt/filter_pmail.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmailcvt/filter_pmail.hxx b/kmailcvt/filter_pmail.hxx
index 664fdcc1b..d3ac1e60a 100644
--- a/kmailcvt/filter_pmail.hxx
+++ b/kmailcvt/filter_pmail.hxx
@@ -32,8 +32,8 @@ public:
void import(FilterInfo *info);
protected:
- /** this looks for all files with the filemask 'mask' and calls the 'workFunc' on each of them */
- void processFiles(const TQString& mask, void(FilterPMail::* workFunc)(const TQString&) );
+ /** this looks for all files with the filetqmask 'tqmask' and calls the 'workFunc' on each of them */
+ void processFiles(const TQString& tqmask, void(FilterPMail::* workFunc)(const TQString&) );
/** this function imports one *.CNM message */
void importNewMessage(const TQString& file);
/** this function imports one mail folder file (*.PMM) */
@@ -53,7 +53,7 @@ private:
/** Folder structure here has 5 entries. */
typedef FolderStructureBase<5> FolderStructure;
- /** List with the folder matrix, which contains following strings:
+ /** List with the folder matrix, which tqcontains following strings:
1. type (2 for root-folder, 1 for folder, 0 for mailarchiv)
2. type (1 for root-folder, 3 for folder, 0 for mailarchiv)
3. "ID:flag:filename" of folder/archiv